---
sidebar_label: data
title: soil.data
---

Defines soil.data()

#### data

```python
def data(data_object: Any,
         metadata: Optional[Dict[str, Any]] = None) -> DataStructure
```

Load data from the cloud or mark it as uploadable

